@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2020 Aurimas Cernius
+ * Copyright (C) 2010-2021 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -48,7 +48,6 @@
 #include "utils.hpp"
 #include "tagmanager.hpp"
 #include "dbus/remotecontrol.hpp"
-#include "dbus/remotecontrolclient.hpp"
 #include "sharp/streamreader.hpp"
 #include "sharp/files.hpp"
 #include "notebooks/notebookmanager.hpp"
@@ -62,7 +61,6 @@ namespace gnote {
     , m_sync_manager(NULL)
     , m_is_background(false)
     , m_is_shell_search(false)
-    , m_remote_control(*this)
     , m_prefsdlg(NULL)
     , m_cmd_line(*this)
   {
@@ -125,6 +123,7 @@ namespace gnote {
     if(!m_manager) {
       common_init();
       register_object();
+      end_main();
     }
     else {
       cmdline.set_note_manager(*m_manager);
@@ -157,40 +156,13 @@ namespace gnote {
   }
 
 
-  void Gnote::end_main(bool bus_acquired, bool name_acquired)
+  void Gnote::end_main()
   {
     m_cmd_line.set_note_manager(*m_manager);
     if(m_cmd_line.needs_execute()) {
       m_cmd_line.execute();
     }
 
-    if(bus_acquired) {
-      if(name_acquired) {
-        DBG_OUT("Gnote remote control active.");
-      } 
-      else {
-        // If Gnote is already running, open the search window
-        // so the user gets some sort of feedback when they
-        // attempt to run Gnote again, except when --background is passed
-        if(!m_is_background) {
-          Glib::RefPtr<RemoteControlClient> remote;
-          try {
-            remote = m_remote_control.get_instance();
-            DBG_ASSERT(remote, "remote is NULL, something is wrong");
-            if(remote) {
-              remote->DisplaySearch();
-            }
-          } 
-          catch (...)
-          {
-          }
-        }
-
-        ERR_OUT(_("Gnote is already running.  Exiting..."));
-        ::exit(-1);
-      }
-    }
-
     make_app_actions();
     if(is_background()) {
       // do not exit when all windows are closed
@@ -223,15 +195,15 @@ namespace gnote {
   }
 
 
-  void Gnote::register_remote_control(NoteManager & manager, RemoteControlProxy::slot_name_acquire_finish on_finish)
-  {
-    m_remote_control.register_remote(manager, on_finish);
-  }
-
-
   void Gnote::register_object()
   {
-    m_remote_control.register_object(Gio::DBus::Connection::get_sync(Gio::DBus::BUS_TYPE_SESSION), default_note_manager(), sigc::mem_fun(*this, &Gnote::end_main));
+    auto conn = get_dbus_connection();
+    if(conn) {
+      m_remote_control.register_object(conn, *this, default_note_manager());
+    }
+    else {
+      ERR_OUT(_("No D-Bus connection available, shell search and remote control will not work."));
+    }
   }
 
 
@@ -292,7 +264,7 @@ namespace gnote {
     about.set_program_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(m_icon_manager.get_icon(IconManager::GNOTE, 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2010-2020 Aurimas Cernius\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2010-2021 Aurimas Cernius\n"
                           "Copyright \xc2\xa9 2009-2011 Debarshi Ray\n"
                           "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
@@ -384,33 +356,19 @@ namespace gnote {
 
     // present already open search window, if there is one
     std::vector<Gtk::Window*> windows = Gtk::Window::list_toplevels();
-    int main_windows = 0;
     for(std::vector<Gtk::Window*>::iterator iter = windows.begin();
         iter != windows.end(); ++iter) {
       auto win = dynamic_cast<MainWindow*>(*iter);
       if(win) {
-        ++main_windows;
         if(win->is_search()) {
           return *win;
         }
-        else if(rc == NULL) {
-          rc = win;
-        }
       }
     }
 
-    // if notes are opened in new window by default, then open new window for search
-    // otherwise switch the only window to search
-    // if there is more than one window open, open new for search, since we can't decide which one to switch
-    bool new_window = m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
-    if(main_windows > 1 || new_window) {
-      MainWindow & main_window = new_main_window();
-      main_window.present_search();
-      return main_window;
-    }
-
-    rc->present_search();
-    return *rc;
+    MainWindow & main_window = new_main_window();
+    main_window.present_search();
+    return main_window;
   }
 
   void Gnote::open_note_sync_window(const Glib::VariantBase&)
@@ -601,17 +559,7 @@ namespace gnote {
     if(remote_control) {
       execute(remote_control);
     }
-    else {
-      //gnote already running, execute via D-Bus and exit this instance
-      Glib::RefPtr<RemoteControlClient> remote = static_cast<Gnote&>(m_gnote).remote_control().get_instance();
-      if(!remote) {
-        ERR_OUT(_("Could not connect to remote instance."));
-      }
-      else {
-        execute(remote);
-      }
-      static_cast<Gnote&>(m_gnote).quit();
-    }
+
     return 0;
   }
 
