@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2013,2016-2017,2019 Aurimas Cernius
+ * Copyright (C) 2010-2013,2016-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -40,26 +40,25 @@ namespace gnote {
     set_right_margin(default_margin());
     property_can_default().set_value(true);
 
-    Glib::RefPtr<Gio::Settings> settings = m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE);
+    m_preferences.signal_enable_custom_font_changed.connect(sigc::mem_fun(*this, &NoteEditor::update_custom_font_setting));
+    m_preferences.signal_custom_font_face_changed.connect(sigc::mem_fun(*this, &NoteEditor::update_custom_font_setting));
     //Set up the schema to watch the default document font
-    Glib::RefPtr<Gio::Settings> desktop_settings = m_preferences
-      .get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
-    if(desktop_settings) {
-      desktop_settings->signal_changed().connect(
-        sigc::mem_fun(*this, &NoteEditor::on_font_setting_changed));
-    }
+    m_preferences.signal_desktop_gnome_font_changed
+      .connect(sigc::mem_fun(*this, &NoteEditor::on_gnome_font_setting_changed));
+
+    // query all monitored settings to get change notifications
+    bool enable_custom_font = m_preferences.enable_custom_font();
+    auto font_string = m_preferences.custom_font_face();
+    auto gnome_font = get_gnome_document_font_description();
 
     // Set Font from preference
-    if (settings->get_boolean(Preferences::ENABLE_CUSTOM_FONT)) {
-      Glib::ustring font_string = settings->get_string(Preferences::CUSTOM_FONT_FACE);
-      override_font (Pango::FontDescription(font_string));
+    if(enable_custom_font) {
+      modify_font_from_string(font_string);
     }
     else {
-      override_font (get_gnome_document_font_description ());
+      override_font(gnome_font);
     }
 
-    settings->signal_changed().connect(sigc::mem_fun(*this, &NoteEditor::on_font_setting_changed));
-
     // Set extra editor drag targets supported (in addition
     // to the default TextView's various text formats)...
     Glib::RefPtr<Gtk::TargetList> list = drag_dest_get_target_list();
@@ -79,47 +78,28 @@ namespace gnote {
   Pango::FontDescription NoteEditor::get_gnome_document_font_description()
   {
     try {
-      Glib::RefPtr<Gio::Settings> desktop_settings = m_preferences
-        .get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
-      if(desktop_settings) {
-        Glib::ustring doc_font_string =
-          desktop_settings->get_string(Preferences::DESKTOP_GNOME_FONT);
-        return Pango::FontDescription(doc_font_string);
-      }
+      auto doc_font_string = m_preferences.desktop_gnome_font();
+      return Pango::FontDescription(doc_font_string);
     } 
     catch (...) {
-
     }
 
     return Pango::FontDescription();
   }
 
 
-  void NoteEditor::on_font_setting_changed (const Glib::ustring & key)
+  void NoteEditor::on_gnome_font_setting_changed()
   {
-    if(key == Preferences::ENABLE_CUSTOM_FONT || key == Preferences::CUSTOM_FONT_FACE) {
-      update_custom_font_setting ();
-    }
-    else if(key == Preferences::DESKTOP_GNOME_FONT) {
-      if (!m_preferences.get_schema_settings(
-          Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::ENABLE_CUSTOM_FONT)) {
-        Glib::RefPtr<Gio::Settings> desktop_settings = m_preferences
-          .get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
-        if(desktop_settings) {
-          Glib::ustring value = desktop_settings->get_string(key);
-          modify_font_from_string(value);
-        }
-      }
+    if(!m_preferences.enable_custom_font()) {
+      override_font(get_gnome_document_font_description());
     }
   }
 
 
   void NoteEditor::update_custom_font_setting()
   {
-    Glib::RefPtr<Gio::Settings> settings = m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE);
-
-    if (settings->get_boolean(Preferences::ENABLE_CUSTOM_FONT)) {
-      Glib::ustring fontString = settings->get_string(Preferences::CUSTOM_FONT_FACE);
+    if (m_preferences.enable_custom_font()) {
+      auto fontString = m_preferences.custom_font_face();
       DBG_OUT( "Switching note font to '%s'...", fontString.c_str());
       modify_font_from_string (fontString);
     } 
@@ -215,20 +195,26 @@ namespace gnote {
     }
   }
 
-  bool NoteEditor::key_pressed (GdkEventKey * ev)
+  bool NoteEditor::key_pressed(GdkEventKey *ev)
   {
       bool ret_value = false;
       if(!get_editable()) {
         return ret_value;
       }
 
-      switch (ev->keyval)
+      guint keyval;
+      GdkModifierType state;
+      GdkEvent *event = (GdkEvent*)ev;
+      if(!gdk_event_get_keyval(event, &keyval) || !gdk_event_get_state(event, &state)) {
+        return false;
+      }
+      switch(keyval)
       {
       case GDK_KEY_KP_Enter:
       case GDK_KEY_Return:
         // Allow opening notes with Ctrl + Enter
-        if (ev->state != Gdk::CONTROL_MASK) {
-          if (ev->state & Gdk::SHIFT_MASK) {
+        if(state != GDK_CONTROL_MASK) {
+          if(state & Gdk::SHIFT_MASK) {
             ret_value = NoteBuffer::Ptr::cast_static(get_buffer())->add_new_line (true);
           } 
           else {
@@ -246,7 +232,7 @@ namespace gnote {
         scroll_to (get_buffer()->get_insert());
         break;
       case GDK_KEY_Delete:
-        if (Gdk::SHIFT_MASK != (ev->state & Gdk::SHIFT_MASK)) {
+        if(Gdk::SHIFT_MASK != (state & Gdk::SHIFT_MASK)) {
           ret_value = NoteBuffer::Ptr::cast_static(get_buffer())->delete_key_handler();
           scroll_to (get_buffer()->get_insert());
         }
