@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013,2017,2019 Aurimas Cernius
+ * Copyright (C) 2011,2013,2017,2019,2021 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 
 #include "debug.hpp"
 #include "dbus/remotecontrol.hpp"
-#include "dbus/remotecontrolclient.hpp"
 #include "dbus/searchprovider.hpp"
 #include "remotecontrolproxy.hpp"
 #include "sharp/files.hpp"
@@ -60,82 +59,25 @@ const char *RemoteControlProxy::GNOTE_SEARCH_PROVIDER_PATH = "/org/gnome/Gnote/S
 const char *RemoteControlProxy::GNOTE_SEARCH_PROVIDER_INTERFACE_NAME = "org.gnome.Shell.SearchProvider2";
 
 
-RemoteControlProxy::RemoteControlProxy(IGnote & g)
-  : m_gnote(g)
-  , m_manager(NULL)
-  , m_remote_control(NULL)
+RemoteControlProxy::RemoteControlProxy()
+  : m_remote_control(NULL)
   , m_search_provider(NULL)
-  , m_bus_acquired(false)
 {
 }
 
-Glib::RefPtr<RemoteControlClient> RemoteControlProxy::get_instance()
-{
-  if(m_remote_control_proxy) {
-    return m_remote_control_proxy;
-  }
-  if(!m_connection) {
-    return Glib::RefPtr<RemoteControlClient>();
-  }
-
-  load_introspection_xml();
-  return m_remote_control_proxy = Glib::RefPtr<RemoteControlClient>(
-    new RemoteControlClient(m_connection, GNOTE_SERVER_PATH, GNOTE_SERVER_NAME, GNOTE_INTERFACE_NAME, m_gnote_interface));
-}
-
 RemoteControl *RemoteControlProxy::get_remote_control()
 {
   return m_remote_control;
 }
 
-void RemoteControlProxy::register_remote(NoteManagerBase & manager, const slot_name_acquire_finish & on_finish)
-{
-  m_on_name_acquire_finish = on_finish;
-  m_manager = &manager;
-  Gio::DBus::own_name(Gio::DBus::BUS_TYPE_SESSION, GNOTE_SERVER_NAME,
-                      sigc::mem_fun(*this, &RemoteControlProxy::on_bus_acquired),
-                      sigc::mem_fun(*this, &RemoteControlProxy::on_name_acquired),
-                      sigc::mem_fun(*this, &RemoteControlProxy::on_name_lost));
-}
 
-
-void RemoteControlProxy::on_bus_acquired(const Glib::RefPtr<Gio::DBus::Connection> & conn, const Glib::ustring &)
-{
-  m_bus_acquired = true;
-  m_connection = conn;
-}
-
-
-void RemoteControlProxy::on_name_acquired(const Glib::RefPtr<Gio::DBus::Connection> & conn, const Glib::ustring &)
-{
-  try {
-    if(m_bus_acquired) {
-      register_object(conn, *m_manager, m_on_name_acquire_finish);
-      return;
-    }
-  }
-  catch(Glib::Exception & e) {
-    DBG_OUT("Failed to acquire name: %s", e.what().c_str());
-  }
-
-  m_on_name_acquire_finish(false, false);
-}
-
-
-void RemoteControlProxy::register_object(const Glib::RefPtr<Gio::DBus::Connection> & conn, NoteManagerBase & manager,
-                                         const slot_name_acquire_finish & on_finish)
+void RemoteControlProxy::register_object(const Glib::RefPtr<Gio::DBus::Connection> & conn, IGnote & g, NoteManagerBase & manager)
 {
   load_introspection_xml();
-  m_remote_control = new RemoteControl(conn, m_gnote, manager, GNOTE_SERVER_PATH, GNOTE_INTERFACE_NAME, m_gnote_interface);
+  m_remote_control = new RemoteControl(conn, g, manager, GNOTE_SERVER_PATH, GNOTE_INTERFACE_NAME, m_gnote_interface);
   m_search_provider = new org::gnome::Gnote::SearchProvider(conn, GNOTE_SEARCH_PROVIDER_PATH,
-                                                            m_search_provider_interface, m_gnote, manager);
-  on_finish(true, true);
-}
-
-
-void RemoteControlProxy::on_name_lost(const Glib::RefPtr<Gio::DBus::Connection> &, const Glib::ustring &)
-{
-  m_on_name_acquire_finish(m_bus_acquired, false);
+                                                            m_search_provider_interface, g, manager);
+  DBG_OUT("Gnote remote control active.");
 }
 
 
