@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019-2021 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -78,7 +78,6 @@ SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
   add2(m_matches_window);
 
   make_recent_tree();
-  m_tree = manage(m_tree);
   m_tree->set_enable_search(false);
   m_tree->show();
 
@@ -106,11 +105,9 @@ SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
   notebook_manager.signal_note_pin_status_changed
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_pin_status_changed));
 
-  Glib::RefPtr<Gio::Settings> settings = g.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
-  settings->signal_changed().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
-  parse_sorting_setting(settings->get_string(Preferences::SEARCH_SORTING));
-  settings = g.preferences().get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
-  settings->signal_changed().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
+  g.preferences().signal_open_notes_in_new_window_changed.connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
+  parse_sorting_setting(g.preferences().search_sorting());
+  g.preferences().signal_desktop_gnome_clock_format_changed.connect(sigc::mem_fun(*this, &SearchNotesWidget::update_results));
 }
 
 SearchNotesWidget::~SearchNotesWidget()
@@ -121,6 +118,9 @@ SearchNotesWidget::~SearchNotesWidget()
   if(m_notebook_list_context_menu) {
     delete m_notebook_list_context_menu;
   }
+  if(m_no_matches_box) {
+    delete m_no_matches_box;
+  }
 }
 
 Glib::ustring SearchNotesWidget::get_name() const
@@ -271,9 +271,7 @@ void SearchNotesWidget::save_position()
     return;
   }
 
-  Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
-    .get_schema_settings(Preferences::SCHEMA_GNOTE);
-  settings->set_int(Preferences::SEARCH_WINDOW_SPLITTER_POS, get_position());
+  m_gnote.preferences().search_window_splitter_pos(get_position());
 
   Gtk::Window *window = dynamic_cast<Gtk::Window*>(current_host);
   if(!window || (window->get_window()->get_state() & Gdk::WINDOW_STATE_MAXIMIZED) != 0) {
@@ -282,8 +280,8 @@ void SearchNotesWidget::save_position()
 
   window->get_size(width, height);
 
-  settings->set_int(Preferences::SEARCH_WINDOW_WIDTH, width);
-  settings->set_int(Preferences::SEARCH_WINDOW_HEIGHT, height);
+  m_gnote.preferences().search_window_width(width);
+  m_gnote.preferences().search_window_height(height);
 }
 
 void SearchNotesWidget::notebook_pixbuf_cell_data_func(Gtk::CellRenderer * renderer,
@@ -412,7 +410,10 @@ void SearchNotesWidget::on_notebook_selection_changed()
 
 bool SearchNotesWidget::on_notebooks_tree_button_pressed(GdkEventButton *ev)
 {
-  if(ev->button == 3) {
+  auto event = (GdkEvent*)ev;
+  guint button;
+  gdk_event_get_button(event, &button);
+  if(button == 3) {
     // third mouse button (right-click)
     Gtk::TreeViewColumn * col = 0; // unused
     Gtk::TreePath p;
@@ -420,12 +421,14 @@ bool SearchNotesWidget::on_notebooks_tree_button_pressed(GdkEventButton *ev)
     const Glib::RefPtr<Gtk::TreeSelection> selection
       = m_notebooksTree->get_selection();
 
-    if(m_notebooksTree->get_path_at_pos(ev->x, ev->y, p, col, cell_x, cell_y)) {
+    gdouble x, y;
+    gdk_event_get_coords(event, &x, &y);
+    if(m_notebooksTree->get_path_at_pos(x, y, p, col, cell_x, cell_y)) {
       selection->select(p);
     }
 
     Gtk::Menu *menu = get_notebook_list_context_menu();
-    popup_context_menu_at_location(menu, reinterpret_cast<GdkEvent*>(ev));
+    popup_context_menu_at_location(menu, event);
     return true;
   }
   return false;
@@ -433,14 +436,17 @@ bool SearchNotesWidget::on_notebooks_tree_button_pressed(GdkEventButton *ev)
 
 bool SearchNotesWidget::on_notebooks_key_pressed(GdkEventKey *ev)
 {
-  switch(ev->keyval) {
+  auto event = (GdkEvent*)ev;
+  guint keyval;
+  gdk_event_get_keyval(event, &keyval);
+  switch(keyval) {
   case GDK_KEY_F2:
     on_rename_notebook();
     break;
   case GDK_KEY_Menu:
   {
     Gtk::Menu *menu = get_notebook_list_context_menu();
-    popup_context_menu_at_location(menu, reinterpret_cast<GdkEvent*>(ev));
+    popup_context_menu_at_location(menu, event);
     break;
   }
   default:
@@ -655,7 +661,7 @@ void SearchNotesWidget::make_recent_tree()
   m_targets.push_back(Gtk::TargetEntry("text/plain", Gtk::TARGET_SAME_APP, 0));
   m_targets.push_back(Gtk::TargetEntry("text/uri-list", Gtk::TARGET_SAME_APP, 1));
 
-  m_tree = Gtk::manage(new RecentTreeView());
+  m_tree = manage(new RecentTreeView());
   m_tree->set_headers_visible(true);
   m_tree->set_rules_hint(true);
   m_tree->signal_row_activated().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_row_activated));
@@ -802,7 +808,8 @@ void SearchNotesWidget::on_selection_changed()
 
 bool SearchNotesWidget::on_treeview_button_pressed(GdkEventButton *ev)
 {
-  if(ev->window != m_tree->get_bin_window()->gobj()) {
+  auto event = (GdkEvent*)ev;
+  if(gdk_event_get_window(event) != m_tree->get_bin_window()->gobj()) {
     return false;
   }
 
@@ -810,16 +817,23 @@ bool SearchNotesWidget::on_treeview_button_pressed(GdkEventButton *ev)
   Gtk::TreeViewColumn *column = NULL;
   int unused;
 
-  m_tree->get_path_at_pos(ev->x, ev->y, dest_path, column, unused, unused);
+  gdouble x, y;
+  gdk_event_get_coords(event, &x, &y);
+  m_tree->get_path_at_pos(x, y, dest_path, column, unused, unused);
 
-  m_clickX = ev->x;
-  m_clickY = ev->y;
+  m_clickX = x;
+  m_clickY = y;
 
   bool retval = false;
 
-  switch(ev->type) {
+  switch(event->type) {
   case GDK_2BUTTON_PRESS:
-    if(ev->button != 1 || (ev->state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) != 0) {
+  {
+    guint button;
+    gdk_event_get_button(event, &button);
+    GdkModifierType state;
+    gdk_event_get_state(event, &state);
+    if(button != 1 || (state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) != 0) {
       break;
     }
 
@@ -831,21 +845,25 @@ bool SearchNotesWidget::on_treeview_button_pressed(GdkEventButton *ev)
     // https://bugzilla.gnome.org/show_bug.cgi?id=586438
     gtk_tree_view_row_activated(m_tree->gobj(), dest_path.gobj(), column?column->gobj():NULL);
     break;
+  }
   case GDK_BUTTON_PRESS:
-    if(ev->button == 3) {
+  {
+    guint button;
+    gdk_event_get_button(event, &button);
+    if(button == 3) {
       const Glib::RefPtr<Gtk::TreeSelection> selection = m_tree->get_selection();
 
       if(selection->get_selected_rows().size() <= 1) {
         Gtk::TreeViewColumn * col = 0; // unused
         Gtk::TreePath p;
         int cell_x, cell_y;            // unused
-        if(m_tree->get_path_at_pos(ev->x, ev->y, p, col, cell_x, cell_y)) {
+        if(m_tree->get_path_at_pos(x, y, p, col, cell_x, cell_y)) {
           selection->unselect_all();
           selection->select(p);
         }
       }
       Gtk::Menu *menu = get_note_list_context_menu();
-      popup_context_menu_at_location(menu, reinterpret_cast<GdkEvent*>(ev));
+      popup_context_menu_at_location(menu, event);
 
       // Return true so that the base handler won't
       // run, which causes the selection to change to
@@ -854,19 +872,17 @@ bool SearchNotesWidget::on_treeview_button_pressed(GdkEventButton *ev)
       break;
     }
 
-    if(m_tree->get_selection()->is_selected(dest_path)
-       && (ev->state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) == 0) {
-      if(column && (ev->button == 1)) {
+    GdkModifierType state;
+    gdk_event_get_state(event, &state);
+    if(m_tree->get_selection()->is_selected(dest_path) && (state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) == 0) {
+      if(column && (button == 1)) {
         Gtk::CellRenderer *renderer = column->get_first_cell();
         Gdk::Rectangle background_area;
         m_tree->get_background_area(dest_path, *column, background_area);
         Gdk::Rectangle cell_area;
         m_tree->get_cell_area(dest_path, *column, cell_area);
 
-        renderer->activate((GdkEvent*)ev, *m_tree,
-                           dest_path.to_string (),
-                           background_area, cell_area,
-                           Gtk::CELL_RENDERER_SELECTED);
+        renderer->activate(event, *m_tree, dest_path.to_string(), background_area, cell_area, Gtk::CELL_RENDERER_SELECTED);
 
         Gtk::TreeIter iter = m_tree->get_model()->get_iter (dest_path);
         if(iter) {
@@ -878,6 +894,7 @@ bool SearchNotesWidget::on_treeview_button_pressed(GdkEventButton *ev)
     }
 
     break;
+  }
   default:
     retval = false;
     break;
@@ -887,39 +904,47 @@ bool SearchNotesWidget::on_treeview_button_pressed(GdkEventButton *ev)
 
 bool SearchNotesWidget::on_treeview_motion_notify(GdkEventMotion *ev)
 {
-  if((ev->state & Gdk::BUTTON1_MASK) == 0) {
+  auto event = (GdkEvent*)ev;
+  GdkModifierType state;
+  gdk_event_get_state(event, &state);
+  if((state & Gdk::BUTTON1_MASK) == 0) {
     return false;
   }
-  else if(ev->window != m_tree->get_bin_window()->gobj()) {
+  else if(gdk_event_get_window(event) != m_tree->get_bin_window()->gobj()) {
     return false;
   }
 
   bool retval = true;
-
-  if(!m_tree->drag_check_threshold(m_clickX, m_clickY, ev->x, ev->y)) {
+  gdouble x, y;
+  gdk_event_get_coords(event, &x, &y);
+  if(!m_tree->drag_check_threshold(m_clickX, m_clickY, x, y)) {
     return retval;
   }
 
   Gtk::TreePath dest_path;
   Gtk::TreeViewColumn * col = NULL; // unused
   int cell_x, cell_y;               // unused
-  if(!m_tree->get_path_at_pos(ev->x, ev->y, dest_path, col, cell_x, cell_y)) {
+  if(!m_tree->get_path_at_pos(x, y, dest_path, col, cell_x, cell_y)) {
     return retval;
   }
 
-  m_tree->drag_begin(Gtk::TargetList::create (m_targets), Gdk::ACTION_MOVE, 1, (GdkEvent*)ev);
+  m_tree->drag_begin(Gtk::TargetList::create (m_targets), Gdk::ACTION_MOVE, 1, event);
   return retval;
 }
 
 bool SearchNotesWidget::on_treeview_button_released(GdkEventButton *ev)
 {
-  if(!m_tree->drag_check_threshold(m_clickX, m_clickY, ev->x, ev->y)
-     && ((ev->state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) == 0)
+  gdouble x, y;
+  gdk_event_get_coords((GdkEvent*)ev, &x, &y);
+  GdkModifierType state;
+  gdk_event_get_state((GdkEvent*)ev, &state);
+  if(!m_tree->drag_check_threshold(m_clickX, m_clickY, x, y)
+     && ((state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) == 0)
      && m_tree->get_selection()->count_selected_rows () > 1) {
     Gtk::TreePath dest_path;
     Gtk::TreeViewColumn * col = NULL; // unused
     int cell_x, cell_y;               // unused
-    m_tree->get_path_at_pos(ev->x, ev->y, dest_path, col, cell_x, cell_y);
+    m_tree->get_path_at_pos(x, y, dest_path, col, cell_x, cell_y);
     m_tree->get_selection()->unselect_all();
     m_tree->get_selection()->select(dest_path);
   }
@@ -930,8 +955,11 @@ bool SearchNotesWidget::on_treeview_key_pressed(GdkEventKey * ev)
 {
   // create context menu here, so that we have shortcuts and they work
   Gtk::Menu *menu = get_note_list_context_menu();
+  auto event = (GdkEvent*)ev;
+  guint keyval;
+  gdk_event_get_keyval(event, &keyval);
 
-  switch(ev->keyval) {
+  switch(keyval) {
   case GDK_KEY_Delete:
     delete_selected_notes();
     break;
@@ -940,7 +968,7 @@ bool SearchNotesWidget::on_treeview_key_pressed(GdkEventKey * ev)
     // Pop up the context menu if a note is selected
     Note::List selected_notes = get_selected_notes();
     if(!selected_notes.empty()) {
-      popup_context_menu_at_location(menu, reinterpret_cast<GdkEvent*>(ev));
+      popup_context_menu_at_location(menu, event);
     }
     break;
   }
@@ -1009,7 +1037,7 @@ void SearchNotesWidget::no_matches_found_action()
     no_matches_found->set_hexpand(true);
     no_matches_found->set_vexpand(true);
     no_matches_found->show_all();
-    m_no_matches_box = manage(new Gtk::Grid);
+    m_no_matches_box = new Gtk::Grid;
     m_no_matches_box->attach(*no_matches_found, 0, 0, 1, 1);
     m_no_matches_box->show();
   }
@@ -1266,11 +1294,9 @@ Gtk::Menu *SearchNotesWidget::get_note_list_context_menu()
 {
   if(!m_note_list_context_menu) {
     m_note_list_context_menu = new Gtk::Menu;
-    bool open_notes_in_new_window = m_gnote.preferences().get_schema_settings(
-      Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
 
     Gtk::MenuItem *item;
-    if(!open_notes_in_new_window) {
+    if(!m_gnote.preferences().open_notes_in_new_window()) {
       item = manage(new Gtk::MenuItem);
       item->set_related_action(m_open_note_action);
       item->add_accelerator("activate", m_accel_group, GDK_KEY_O, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
@@ -1375,13 +1401,10 @@ void SearchNotesWidget::foreground()
   }
 
   win->add_accel_group(m_accel_group);
-  win->set_focus(*m_tree);
   auto & manager(m_gnote.action_manager());
   register_callbacks();
   m_callback_changed_cid = manager.signal_main_window_search_actions_changed
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::callbacks_changed));
-  manager.signal_main_window_search_actions_changed
-    .connect([this]{ signal_popover_widgets_changed(); });
 }
 
 void SearchNotesWidget::background()
@@ -1398,22 +1421,26 @@ void SearchNotesWidget::background()
 
 void SearchNotesWidget::hint_size(int & width, int & height)
 {
-  Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
-    .get_schema_settings(Preferences::SCHEMA_GNOTE);
-  width = settings->get_int(Preferences::SEARCH_WINDOW_WIDTH);
-  height = settings->get_int(Preferences::SEARCH_WINDOW_HEIGHT);
+  width = m_gnote.preferences().search_window_width();
+  height = m_gnote.preferences().search_window_height();
 }
 
 void SearchNotesWidget::size_internals()
 {
-  Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences()
-    .get_schema_settings(Preferences::SCHEMA_GNOTE);
-  int pos = settings->get_int(Preferences::SEARCH_WINDOW_SPLITTER_POS);
+  int pos = m_gnote.preferences().search_window_splitter_pos();
   if(pos) {
     set_position(pos);
   }
 }
 
+void SearchNotesWidget::set_initial_focus()
+{
+  Gtk::Window *win = dynamic_cast<Gtk::Window*>(host());
+  if(win) {
+    win->set_focus(*m_tree);
+  }
+}
+
 std::vector<PopoverWidget> SearchNotesWidget::get_popover_widgets()
 {
   std::vector<PopoverWidget> popover_widgets;
@@ -1431,16 +1458,11 @@ std::vector<MainWindowAction::Ptr> SearchNotesWidget::get_widget_actions()
   return actions;
 }
 
-void SearchNotesWidget::on_settings_changed(const Glib::ustring & key)
+void SearchNotesWidget::on_settings_changed()
 {
-  if(key == Preferences::OPEN_NOTES_IN_NEW_WINDOW) {
-    if(m_note_list_context_menu) {
-      delete m_note_list_context_menu;
-      m_note_list_context_menu = NULL;
-    }
-  }
-  else if(key == Preferences::DESKTOP_GNOME_CLOCK_FORMAT) {
-    update_results();
+  if(m_note_list_context_menu) {
+    delete m_note_list_context_menu;
+    m_note_list_context_menu = NULL;
   }
 }
 
@@ -1470,8 +1492,7 @@ void SearchNotesWidget::on_sorting_changed()
     else {
       value += "desc";
     }
-    m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
-      Preferences::SEARCH_SORTING, value);
+    m_gnote.preferences().search_sorting(value);
   }
 }
 
@@ -1480,7 +1501,7 @@ void SearchNotesWidget::parse_sorting_setting(const Glib::ustring & sorting)
   std::vector<Glib::ustring> tokens;
   sharp::string_split(tokens, sorting.lowercase(), ":");
   if(tokens.size() != 2) {
-    ERR_OUT(_("Failed to parse setting %s (Value: %s):"), Preferences::SEARCH_SORTING, sorting.c_str());
+    ERR_OUT(_("Failed to parse setting search-sorting (Value: %s):"), sorting.c_str());
     ERR_OUT(_("Expected format 'column:order'"));
     return;
   }
@@ -1493,7 +1514,7 @@ void SearchNotesWidget::parse_sorting_setting(const Glib::ustring & sorting)
     column_id = 2;
   }
   else {
-    ERR_OUT(_("Failed to parse setting %s (Value: %s):"), Preferences::SEARCH_SORTING, sorting.c_str());
+    ERR_OUT(_("Failed to parse setting search-sorting (Value: %s):"), sorting.c_str());
     ERR_OUT(_("Unrecognized column %s"), tokens[0].c_str());
     return;
   }
@@ -1504,7 +1525,7 @@ void SearchNotesWidget::parse_sorting_setting(const Glib::ustring & sorting)
     order = Gtk::SORT_DESCENDING;
   }
   else {
-    ERR_OUT(_("Failed to parse setting %s (Value: %s):"), Preferences::SEARCH_SORTING, sorting.c_str());
+    ERR_OUT(_("Failed to parse setting search-sorting (Value: %s):"), sorting.c_str());
     ERR_OUT(_("Unrecognized order %s"), tokens[1].c_str());
     return;
   }
@@ -1530,6 +1551,7 @@ void SearchNotesWidget::callbacks_changed()
 {
   unregister_callbacks();
   register_callbacks();
+  signal_popover_widgets_changed();
 }
 
 void SearchNotesWidget::register_callbacks()
